Enum rusoto_codebuild::CreateWebhookError [−][src]
pub enum CreateWebhookError {
InvalidInput(String),
OAuthProvider(String),
ResourceAlreadyExists(String),
ResourceNotFound(String),
HttpDispatch(HttpDispatchError),
Credentials(CredentialsError),
Validation(String),
Unknown(String),
}Errors returned by CreateWebhook
Variants
InvalidInput(String)The input value that was provided is not valid.
OAuthProvider(String)There was a problem with the underlying OAuth provider.
ResourceAlreadyExists(String)The specified AWS resource cannot be created, because an AWS resource with the same settings already exists.
ResourceNotFound(String)The specified AWS resource cannot be found.
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
Unknown(String)An unknown error occurred. The raw HTTP response is provided.
Methods
impl CreateWebhookError[src]
impl CreateWebhookErrorpub fn from_body(body: &str) -> CreateWebhookError[src]
pub fn from_body(body: &str) -> CreateWebhookErrorTrait Implementations
impl Debug for CreateWebhookError[src]
impl Debug for CreateWebhookErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for CreateWebhookError[src]
impl PartialEq for CreateWebhookErrorfn eq(&self, other: &CreateWebhookError) -> bool[src]
fn eq(&self, other: &CreateWebhookError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &CreateWebhookError) -> bool[src]
fn ne(&self, other: &CreateWebhookError) -> boolThis method tests for !=.
impl From<Error> for CreateWebhookError[src]
impl From<Error> for CreateWebhookErrorfn from(err: Error) -> CreateWebhookError[src]
fn from(err: Error) -> CreateWebhookErrorPerforms the conversion.
impl From<CredentialsError> for CreateWebhookError[src]
impl From<CredentialsError> for CreateWebhookErrorfn from(err: CredentialsError) -> CreateWebhookError[src]
fn from(err: CredentialsError) -> CreateWebhookErrorPerforms the conversion.
impl From<HttpDispatchError> for CreateWebhookError[src]
impl From<HttpDispatchError> for CreateWebhookErrorfn from(err: HttpDispatchError) -> CreateWebhookError[src]
fn from(err: HttpDispatchError) -> CreateWebhookErrorPerforms the conversion.
impl From<Error> for CreateWebhookError[src]
impl From<Error> for CreateWebhookErrorfn from(err: Error) -> CreateWebhookError[src]
fn from(err: Error) -> CreateWebhookErrorPerforms the conversion.
impl Display for CreateWebhookError[src]
impl Display for CreateWebhookErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for CreateWebhookError[src]
impl Error for CreateWebhookErrorAuto Trait Implementations
impl Send for CreateWebhookError
impl Send for CreateWebhookErrorimpl Sync for CreateWebhookError
impl Sync for CreateWebhookError