pub struct EnvironmentVariable {
pub name: String,
pub type_: Option<String>,
pub value: String,
}Expand description
Information about an environment variable for a build project or a build.
Fields
name: StringThe name or key of the environment variable.
type_: Option<String>The type of environment variable. Valid values include:
-
PARAMETERSTORE: An environment variable stored in Amazon EC2 Systems Manager Parameter Store. To learn how to specify a parameter store environment variable, see parameter store reference-key in the buildspec file. -
PLAINTEXT: An environment variable in plain text format. This is the default value. -
SECRETSMANAGER: An environment variable stored in AWS Secrets Manager. To learn how to specify a secrets manager environment variable, see secrets manager reference-key in the buildspec file.
value: StringThe value of the environment variable.
We strongly discourage the use of PLAINTEXT environment variables to store sensitive values, especially AWS secret key IDs and secret access keys. PLAINTEXT environment variables can be displayed in plain text using the AWS CodeBuild console and the AWS Command Line Interface (AWS CLI). For sensitive values, we recommend you use an environment variable of type PARAMETERSTORE or SECRETSMANAGER.